from find_libpython import find_libpython
import ctypes
import sys


def test_find_libpython():
    # find path
    path = find_libpython()
    # ensure we have a path
    assert path is not None
    # check to ensure it is a libpython share object
    lib = ctypes.CDLL(path)
    assert hasattr(lib, "Py_Initialize")
    # ensure it's the right version...
    lib.Py_GetVersion.restype = ctypes.c_char_p
    lib_version = lib.Py_GetVersion().decode().split()[0]
    curr_version = sys.version.split()[0]
    assert lib_version == curr_version



import nox
import os.path


test_reqs = ["pytest", "pytest-cov"]

pytest_cov_args = ["--cov=find_libpython", "--cov-branch"]


@nox.session
def tests(session):

    # install current module and runtime dependencies
    session.install(".")

    # print info
    session.run("python", "-m", "find_libpython", "--candidate-names")
    session.run("python", "-m", "find_libpython", "--candidate-paths")
    session.run("python", "-m", "find_libpython", "-v")

    # install testing dependencies
    session.install(*test_reqs)

    # run pytest
    install_loc = session.run(
        "python",
        "-c",
        "import find_libpython; print(find_libpython.__file__)",
        silent=True,
    )
    install_loc = os.path.dirname(install_loc.strip())
    session.run("pytest", *pytest_cov_args, "tests/")
    session.run(
        "pytest", *pytest_cov_args, "--cov-append", "--doctest-modules", install_loc
    )
